@@ -1,8 +1,10 @@
 # coding=utf-8
 from __future__ import absolute_import, print_function
 
+import os
 import json
 import base64
+import traceback
 from suanpan.g import g
 from suanpan.log import logger
 from suanpan.base import Context
@@ -11,7 +13,6 @@ from suanpan.arguments import suanpanTypes
 
 
 class APP:
-
     def __init__(self):
         self.func = None
         self.afterInitFunc = None
@@ -42,28 +43,42 @@ class APP:
 
     def __call__(self, func):
         self.func = func if func else self.func
-    
+
     def afterInit(self, func):
         self.afterInitFunc = func if func else self.afterInitFunc
 
     def start(self):
         logger.info("Start Running...")
-        self.paramContext = self.loadParams(g)
-        if self.afterInitFunc:
-            self.afterInitFunc(Context(args=self.paramContext))
+        try:
+            self.paramContext = self.loadParams(g)
+            if self.afterInitFunc:
+                self.afterInitFunc(Context(args=self.paramContext))
+        except Exception as e:
+            tracebackInfo = traceback.format_exc()
+            logger.error(
+                f"Load parameters or Run afterinit function error: {tracebackInfo}"
+            )
+            os._exit(0)
         for context in stream.subscribeMessage():
-            inputContext = self.loadInputs(context)
-            context.args.update({**self.paramContext, **inputContext})
-            result = self.func(context)
-            if result is not None:
-                self.send(result, context)
-            logger.debug("Finshed, Waiting for Next Round...")
+            try:
+                inputContext = self.loadInputs(context)
+                context.args.update({**self.paramContext, **inputContext})
+                result = self.func(context)
+                if result is not None:
+                    self.send(result, context)
+                logger.debug("Finshed, Waiting for Next Round...")
+            except Exception as e:
+                tracebackInfo = traceback.format_exc()
+                logger.error(
+                    f"Load input or Run main function error: {tracebackInfo}")
+                continue
 
     def addArguments(self, configs):
         arguments = {}
         for key, value in configs.items():
             arguments.update({
-                key: suanpanTypes[value["type"]](key=key, alias=value["uuid"])
+                key:
+                suanpanTypes[value["type"]](key=key, alias=value["uuid"])
             })
         return arguments
 
@@ -89,7 +104,8 @@ class APP:
         params = {}
         for k, v in context.items():
             if k.startswith("out") and k[-1].isdigit():
-                result = self.outputArgs[k.replace("out", "outputData")].dump(v)
+                result = self.outputArgs[k.replace("out",
+                                                   "outputData")].dump(v)
                 for port, value in result.items():
                     if port.startswith("out"):
                         port = port.replace(
